// pages/store/store.js
const app = getApp()
var amapFile = require('../../libs/amap-wx.js');
Page({

  /**
   * 页面的初始数据
   */
  data: {
    key: '', //检索关键字
    multiArray: [
      [],
      []
    ], //省份列表
    showMultArray: [
      [],
      []
    ], //省份显示列表
    multiIndex: [0, 0], //省份下标
    multiData: null, //省份数据
    cur_page: 1, //当前页数
    show_num: 10, //每页显示项目数
    storeList: [], //门店列表
    state: 0, //0未获取 1获取中 2无更多
    addressData: null, //地址信息
    locationData: null, //经纬度信息
  },
  /**
   * 清除搜索内容
   */
  clearSearchContent() {
    this.setData({
      key: "",
      cur_page: 1
    })
    this.search()
  },
  /**
   * 输入内容改变
   */
  changeSearch(event) {
    this.setData({
      key: event.detail.value
    })
  },
  /**
   *搜索
   */
  search() {
    this.setData({
      cur_page: 1
    })
    this.getStoreList();
  },
  /**
   * 拨打电话
   */
  callMobile(e) {
    wx.makePhoneCall({
      phoneNumber: e.currentTarget.dataset.mobile
    })
  },
  /**
   * 打开定位地图
   */
  openLocation(e) {
    var latitude = parseFloat(e.currentTarget.dataset.latitude);
    var longitude = parseFloat(e.currentTarget.dataset.longitude);
    var shopName = e.currentTarget.dataset.name;
    wx.openLocation({
      latitude: latitude,
      longitude: longitude,
      scale: 18,
      name: shopName
    })
  },
  /**
   * 获取当前城市 
   */
  getCurrentCity() {
    var that = this
    var myAmapFun = new amapFile.AMapWX({
      key: 'b61cd7baf9244dd531eb27d227218a34'
    });
    myAmapFun.getRegeo({
      success: function(res) {
        //成功回调
        that.setData({
          addressData: res[0].regeocodeData.addressComponent,
          locationData: {
            latitude: res[0].latitude,
            longitude: res[0].longitude
          }
        })
        console.log(res)
        that.getProvince();
      },
      fail: function(info) {
        //失败回调
        that.getProvince();
      }
    })
  },
  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function(options) {
    wx.hideShareMenu();
    this.getCurrentCity()
  },
  /**
   * 获取省份信息
   */
  getProvince() {
    app.requestGet('shop/shop_province', '', res => {
      if (res.code == 200) {
        var city = '全部';
        for (var i = 0; i < res.data.length; i++) {
          city += "," + res.data[i].shop_city
        }
        var indexList = [0, 0]
        if (this.data.addressData){
          var cityList = city.split(',')
          var cityIndex = cityList.indexOf(this.data.addressData.city)
          if (cityIndex > 0) {
            indexList[1] = cityIndex;
          }
        }

        res.data.unshift({
          shop_city: city,
          shop_province: '全部'
        })
        this.setData({
          multiData: res.data,
          multiIndex: indexList
        })
        this.changeCityList(indexList, true);
        this.getStoreList();
      }
    })
  },
  /**
   * 选择省市
   */
  changeCityList(showList, boolem) {
    var data = this.data.multiData;
    var list = [],
      list2;
    for (var i = 0; i < data.length; i++) {
      list.push(data[i].shop_province)
      if (i == showList[0]) {
        list2 = data[i].shop_city.split(',')
      }
    }
    if (boolem) {
      this.setData({
        multiArray: [list, list2],
        showMultArray: [list, list2],
        multiIndex: showList
      })
    } else {
      this.setData({
        multiArray: [list, list2]
      })
    }
  },
  bindMultiPickerColumnChange(e) {
    if (e.detail.column == 0) { //省份改变
      this.changeCityList([e.detail.value, 0], false)
    }
  },
  bindMultiPickerChange(e) {
    this.changeCityList(e.detail.value, true);
    this.setData({
      cur_page: 1
    })
    this.getStoreList();
  },
  bindMultiPickerCancelChange(e) {
    this.changeCityList(this.data.multiIndex, true);
  },
  /**
   * 获取门店列表数据
   */
  getStoreList() {
    if (this.data.cur_page == 1) {
      this.setData({
        storeList: []
      })
    }
    var city = this.data.showMultArray[1][this.data.multiIndex[1]] == '全部' ? '' : this.data.showMultArray[1][this.data.multiIndex[1]];
    var data = {
      'shop_city': city,
      'key': this.data.key,
      'cur_page': this.data.cur_page,
      'show_num': this.data.show_num,
      "location": this.data.locationData ? 2 : 1,
      "lng": this.data.locationData ? this.data.locationData.longitude : null,
      "lat": this.data.locationData ? this.data.locationData.latitude : null,
    }
    app.requestGet('shop/shopsearch', data, res => {
      if (res.code === 200) {
        var newList = JSON.parse(JSON.stringify(this.data.storeList))
        for (var i = 0; i < res.data.length; i++) {
          newList.push(res.data[i])
        }
        if (res.data.length < this.data.show_num) {
          this.setData({
            storeList: newList,
            state: 2
          })
        } else {
          this.setData({
            storeList: newList,
            state: 0
          })
        }
      } else {
        wx.showToast({
          title: res.message,
          icon: 'none',
          duration: 2000
        })
        this.setData({
          state: 0
        })
      }
    })
  },
  /**
   * 滚动到底部
   */
  scrollDown() {
    if (this.data.state == 0) {
      this.setData({
        state: 1,
        cur_page: this.data.cur_page + 1
      })
      this.getStoreList()
    }
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function() {

  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function() {

  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide: function() {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload: function() {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function() {

  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function() {

  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function() {

  }
})